# Example with simulated data

This examples simulates data using the complete model (model 2 from the paper)
and then performs inference using the analytic model (model 3).

The code can be run using the following command

```bash
bayesbeat_run simulated_data.ini
```
